Documentation
¶
Overview ¶
Package gocqlastra provides a custom gocql.HostDialer that enables gocql to connect to DataStax Astra.
Version Notice ¶
This is version 1.x of gocql-astra. If you are looking to use gocql 2.x, please use the v2 module:
go get github.com/datastax/gocql-astra/v2
Documentation: https://pkg.go.dev/github.com/datastax/gocql-astra/v2
The v2 documentation contains an upgrade guide to help you migrate from v1.x to v2.x.
Getting Started ¶
For quickstart tips, usage examples, and detailed information, please see the README above.
Index ¶
- Constants
- func NewCluster(dialer gocql.HostDialer, username, password string) *gocql.ClusterConfig
- func NewClusterFromBundle(path, username, password string, timeout time.Duration) (*gocql.ClusterConfig, error)
- func NewClusterFromURL(url, databaseID, token string, timeout time.Duration) (*gocql.ClusterConfig, error)
- func NewDialer(b *astra.Bundle, timeout time.Duration) (gocql.HostDialer, error)
- func NewDialerFromBundle(path string, timeout time.Duration) (gocql.HostDialer, error)
- func NewDialerFromURL(url, databaseID, token string, timeout time.Duration) (gocql.HostDialer, error)
Constants ¶
const AstraAPIURL = "https://api.astra.datastax.com"
Variables ¶
This section is empty.
Functions ¶
func NewCluster ¶
func NewCluster(dialer gocql.HostDialer, username, password string) *gocql.ClusterConfig
func NewClusterFromBundle ¶
func NewClusterFromURL ¶
func NewDialerFromBundle ¶
func NewDialerFromURL ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.